@@ -192,7 +192,7 @@ void MainFrame::NewPattern(const wxString& title)
         return;
     }
     
-    if (askonnew && !inscript && currlayer->dirty && !SaveCurrentLayer()) return;
+    if (askonnew && currlayer->dirty && !SaveCurrentLayer()) return;
     
     if (inscript) stop_after_script = true;
     currlayer->savestart = false;
@@ -307,7 +307,7 @@ void MainFrame::LoadPattern(const wxString& path, const wxString& newtitle,
     
     // newtitle is only empty if called from ResetPattern/RestorePattern
     if (!newtitle.IsEmpty()) {
-        if (askonload && !inscript && currlayer->dirty && !SaveCurrentLayer()) return;
+        if (askonload && currlayer->dirty && !SaveCurrentLayer()) return;
         
         if (inscript) stop_after_script = true;
         currlayer->savestart = false;
@@ -1592,6 +1592,13 @@ bool MainFrame::SavePattern()
         return false;
     }
     
+    if (warn_on_save && currlayer->dirty && currlayer->algo->getGeneration() > currlayer->startgen) {
+        wxString msg = _("Saving this generation will not save the changes you made earlier, ");
+        msg +=         _("so you might want to select Reset or Undo and save those changes.");
+        msg +=         _("\n\n(This warning can be disabled in Preferences > Layer.)");
+        Warning(msg);
+    }
+
     wxString filetypes;
     int MCindex, RLEindex;
     
